from bs4 import BeautifulSoup as bs
import requests
import sys
import re

class ResultContainer:
    status = None
    message = None
    title = None
    query = None

    def __init__(self, status, message, title, query):
        self.status = status
        self.message = message
        self.title = title
        self.query = query

    def call_info(self):
        return {
            'status': self.status,
            'message': self.message,
            'title': self.title,
            'query': self.query
        }

def fetch_title(url):
    status = None
    message = None
    title = None
    try:
        soup = bs(requests.get(url).text, 'lxml')
        status = 'OK'
        message = 'fetching title success.'
        try:
            title = soup.title.string
        except AttributeError as err:
            title = re.sub('https?://', '', url)
    except requests.exceptions.MissingSchema as err:
        status = 'ERR'
        message = str(err)        
    result = ResultContainer(status, message, title, url).call_info()
    return result

def main(url):
    content = fetch_title(url)
    print(content)

if __name__ == '__main__':
    url = sys.argv[1]
    content = main(url)


from setuptools import setup
from codecs import open
from os import path
package_name = "fetchhtmlinfo"
root_dir = path.abspath(path.dirname(__file__))
def _requirements():
    return [name.rstrip() for name in open(path.join(root_dir, 'requirements.txt')).readlines()]
with open('README.md', encoding='utf-8') as f:
    long_description = f.read()
setup(
    name=package_name,
    version='0.0.6',
    description='Fetch a header info from header tag in HTML file.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/laprn/fetch_title.git',
    author='laprn',
    author_email='y.mrt@tuta.io',
    license='MIT',
    keywords='title',
    packages=[package_name],
    install_requires=_requirements(),
    classifiers=[
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
)